@@ -19,8 +19,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <assert.h>
-#ifdef HAVE_GNUTLS_GNUTLS_H
-#define USE_GNUTLS
+#ifdef USE_GNUTLS
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
 #include <sys/stat.h>
@@ -29,9 +28,9 @@
 #include <dmalloc.h>
 #endif
 
-#include "tlsComm.h"
-
 #include "Client.h"				/* debugging messages */
+#include "tlsComm.h"
+#include "wmbiff.h"
 
 /* if non-null, set to a file for certificate verification */
 extern const char *certificate_filename;
@@ -101,9 +100,6 @@ void tlscomm_close(struct connection_state *scs)
 	free(scs);
 }
 
-extern int x_socket(void);
-extern void ProcessPendingEvents(void);
-
 /* this avoids blocking without using non-blocking i/o */
 static int wait_for_it(int sd, int timeoutseconds)
 {
