@@ -1,9 +1,9 @@
 /* dock.c- built-in Dock module for WindowMaker
- * 
+ *
  *  WindowMaker window manager
- * 
+ *
  *  Copyright (c) 1997 Alfredo K. Kojima
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,12 +16,11 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <stdlib.h>
 #include <string.h>
-#include "list.h"
 #include "misc.h"
 
 extern pid_t execCommand(const char *command)
