@@ -36,7 +36,7 @@ typedef struct {
  /* Global variable */
 /*******************/
 
-Display *display;
+extern Display *display;
 
   /***********************/
  /* Function Prototypes */
